@@ -4,3 +4,7 @@
                         \nSong, Y. (2022). Geographically Optimal Similarity. Mathematical Geosciences. doi: 10.1007/s11004-022-10036-8.
                         ")
 }
+
+.onLoad = function(...) {
+  loadNamespace("tibble")
+}
